@@ -100,6 +100,11 @@ enum {
 	NUM_PAGES
 };
 
+enum {
+	IPV4,
+	IPV6
+};
+
 #endif  /* __NETINFO__ */
 
 /* Generic functions */
@@ -110,6 +115,7 @@ void netinfo_text_buffer_insert (Netinfo * netinfo);
 gushort netinfo_get_count (Netinfo * netinfo);
 const gchar * netinfo_get_host (Netinfo * netinfo);
 const gchar * netinfo_get_user (Netinfo * netinfo);
+gint netinfo_get_ip_version (Netinfo * netinfo);
 void netinfo_toggle_button (Netinfo * netinfo);
 void netinfo_toggle_state (Netinfo * netinfo, gboolean state,
 			   gpointer user_data);
