@@ -26,7 +26,7 @@
 #include "ping.h"
 #include "utils.h"
 
-static gint strip_line (gchar * line, ping_data * data);
+static gint strip_line (gchar * line, ping_data * data, Netinfo * netinfo);
 static gint strip_total_line (gchar * line, gint * packet_total);
 static GtkTreeModel *ping_create_model (GtkTreeView * widget);
 static gboolean ping_output_foreach (GtkTreeModel * model, GtkTreePath * path,
@@ -59,6 +59,7 @@ ping_do (Netinfo * netinfo)
 	gchar stmp[128];
 	gchar *program;
 	GtkWidget *parent;
+	gint ip_version;
 
 	g_return_if_fail (netinfo != NULL);
 
@@ -104,20 +105,43 @@ ping_do (Netinfo * netinfo)
 	gtk_text_buffer_delete (buffer, &start, &end);
 */
 	parent = gtk_widget_get_toplevel (netinfo->output);
-	
-	program = util_find_program_dialog ("ping", parent);
+
+	ip_version = netinfo_get_ip_version (netinfo);
+	switch (ip_version)
+	{
+	case IPV4:
+		program = util_find_program_dialog ("ping", parent);
+		break;
+	case IPV6:
+		program = util_find_program_dialog ("ping6", parent);
+		
+		break;
+	case -1:
+		/*invalid host or ip address*/
+		return;
+	}
 	
 	if (program != NULL) {
 #if defined(__sun__) || defined(__hpux__)
-		command =
-			g_strdup_printf (PING_PROGRAM_FORMAT, program, host,
-	//	    g_strdup_printf (PING_PROGRAM_FORMAT, PING_PROGRAM, host,
-					 count);
+		if (ip_version == IPV4)
+			command =
+				g_strdup_printf (PING_PROGRAM_FORMAT, program, host,
+	 //	    g_strdup_printf (PING_PROGRAM_FORMAT, PING_PROGRAM, host,	
+						 count);
+		else
+			command =
+				g_strdup_printf (PING_PROGRAM_FORMAT_6, program, host,
+						 count);
 #else
-		command =
-			g_strdup_printf (PING_PROGRAM_FORMAT, program, count,
+		if (ip_version == IPV4)
+			command =
+				g_strdup_printf (PING_PROGRAM_FORMAT, program, count,
 	//	    g_strdup_printf (PING_PROGRAM_FORMAT, PING_PROGRAM, count,
-					 host);
+						 host);
+		else
+			command =
+				g_strdup_printf (PING_PROGRAM_FORMAT_6, program, count,
+						 host);
 #endif
 
 /*	command =
@@ -195,7 +219,7 @@ ping_foreach_with_tree (Netinfo * netinfo, gchar * line, gint len,
 	pkt_loss = GTK_LABEL (netinfo->packets_loss);
 
 	if (len > 0) {		/* there are data to show */
-		count = strip_line (line, &data);
+		count = strip_line (line, &data, netinfo);
 		if ((count == 5) || (count == 6)) {
 
 			/* Creation of GtkTreeView */
@@ -303,11 +327,13 @@ ping_foreach_with_tree (Netinfo * netinfo, gchar * line, gint len,
 }
 
 static gint
-strip_line (gchar * line, ping_data * data)
+strip_line (gchar * line, ping_data * data, Netinfo * netinfo)
 {
 	gint count;
 
-	line = g_strdelimit (line, ":", ' ');
+	if (netinfo_get_ip_version (netinfo) == IPV4)
+		line = g_strdelimit (line, ":", ' ');
+
 #ifdef PING_PARAMS_5
 	count = sscanf (line, PING_FORMAT,
 			&(data)->bytes, data->ip, &(data)->icmp_seq,
@@ -321,6 +347,7 @@ strip_line (gchar * line, ping_data * data)
 	if (count != 5 && count != 6) {
 
 	}
+	/*printf ("DBG: bytes: %d, ip: %s, icmp_seq: %d\n", data->bytes, data->ip, data->icmp_seq);*/
 	return count;
 }
 
